@@ -60,7 +60,8 @@ class AbstractSICConnector(object):
                                          'memory_get_interactant_data_all', 'memory_get_all_interactants',
                                          'memory_set_interactant', 'memory_set_dialog_history',
                                          'memory_get_dialog_history_all',
-                                         'memory_delete_interactant', 'memory_delete_all_interactants'],
+                                         'memory_delete_interactant', 'memory_delete_all_interactants',
+                                         'memory_get_move_history', 'memory_set_move_history'],
             self.device_types['speaker']: ['audio_language', 'action_say', 'action_speech_param', 'action_say_animated', 'action_play_audio',
                                            'action_stop_talking', 'action_load_audio', 'action_clear_loaded_audio',
                                            'text_to_speech', 'tts_key', 'tts_voice'],
@@ -652,6 +653,13 @@ class AbstractSICConnector(object):
     def get_dialog_history_all(self):
         self.__send('memory_get_dialog_history_all', '')
 
+    def get_move_history(self, interactant_id: str):
+        self.__send('memory_get_move_history', interactant_id)
+
+    def set_move_history(self, interactant_id: str, move: str):
+        self.__send('memory_set_move_history', f'{interactant_id};{move}')
+
+
     ###########################
     # Browser Actions         #
     ###########################
