@@ -728,6 +728,16 @@ class BasicSICConnector(AbstractSICConnector):
         self.__process_action(super(BasicSICConnector, self).delete_all_interactants,
                               callback=callback, event='AllInteractantsDeleted', sync=sync, load=load)
 
+    def set_move_history(self, interactant_id: str, move: str,
+                         callback: callable = None, sync: bool = True, load: bool = False) -> None:
+        self.__process_action(super(BasicSICConnector, self).set_move_history, interactant_id, move,
+                              callback=callback, event='MoveHistorySet', sync=sync, load=load)
+
+    def get_move_history(self, interactant_id: str,
+                         callback: callable = None, sync: bool = True, load: bool = False) -> None:
+        self.__process_action(super(BasicSICConnector, self).get_move_history, interactant_id,
+                              callback=callback, event='MoveHistory', sync=sync, load=load, memory=True)
+
     ###########################
     # Listeners Management  #
     ###########################
